[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[minion-cvs] Change help messages to refer to mixminiond FOO instead...



Update of /home/minion/cvsroot/src/minion/lib/mixminion/server
In directory moria.mit.edu:/tmp/cvs-serv8060/server

Modified Files:
	ServerMain.py 
Log Message:
Change help messages to refer to mixminiond FOO instead of mixminion server-FOO

Index: ServerMain.py
===================================================================
RCS file: /home/minion/cvsroot/src/minion/lib/mixminion/server/ServerMain.py,v
retrieving revision 1.121
retrieving revision 1.122
diff -u -d -r1.121 -r1.122
--- ServerMain.py	7 Mar 2004 06:31:46 -0000	1.121
+++ ServerMain.py	23 Mar 2004 00:09:06 -0000	1.122
@@ -131,7 +131,7 @@
             print >>sys.stderr, """\
 This server's files are stored in an older format, and are not compatible
 with this version of the mixminion server.  To upgrade, run:
-     'mixminion server-upgrade'."""
+     'mixminiond upgrade'."""
             raise UIError
         else:
             print >>sys.stderr, """\
@@ -688,7 +688,7 @@
 
         # Try to read the keyring.  If we have a pre-0.0.4 version of
         # mixminion, we might have some bad server descriptors lying
         # around.  If so, tell the user to run server-upgrade.
         try:
             self.keyring = mixminion.server.ServerKeys.ServerKeyring(config)
         except mixminion.Config.ConfigError, e:
@@ -703,8 +703,8 @@
             else:
                 raise UIError((
 "For some reason, your generated server descriptors cannot be parsed.  You\n"
-"may want to delete all your keysets with server-DELKEYS and have the server\n"
-"generate new ones.  [Messages sent to the old keys will be lost].\n"
+"may want to delete all your keysets with mixminiond DELKEYS and have the\n"
+"server generate new ones.  [Messages sent to the old keys will be lost].\n"
 "The original error message was '%s'.")%e)
 
         self.keyring.removeDeadKeys()
@@ -1117,6 +1117,7 @@
             p = os.path.expanduser(p)
             if os.path.exists(p):
                 configFile = p
+                break
         if configFile is None:
             print >>sys.stderr, "No config file found or specified."
             sys.exit(1)
@@ -1137,7 +1138,7 @@
 
 #----------------------------------------------------------------------
 _SERVER_START_USAGE = """\
-Usage: mixminion server-start [options]
+Usage: mixminiond start [options]
 Start a Mixminion server.
 Options:
   -h, --help:                Print this usage message and exit.
@@ -1152,7 +1153,7 @@
 def runServer(cmd, args):
     """[Entry point]  Start a Mixminion server."""
     if cmd.endswith(" server"):
-        print "Obsolete command. Use 'mixminion server-start' instead."
+        print "Obsolete command. Use 'mixminiond start' instead."
 
     config = configFromServerArgs(cmd, args, _SERVER_START_USAGE)
     checkHomedirVersion(config)
@@ -1230,7 +1231,7 @@
 
 #----------------------------------------------------------------------
 _UPGRADE_USAGE = """\
-Usage: mixminion server-upgrade [options]
+Usage: mixminiond upgrade [options]
 Upgrade the server's home directory from an earlier version.
 Options:
   -h, --help:                Print this usage message and exit.
@@ -1318,7 +1319,7 @@
 
 #----------------------------------------------------------------------
 _DELKEYS_USAGE = """\
-Usage: mixminion server-DELKEYS [options]
+Usage: mixminiond DELKEYS [options]
 Delete all keys for this server (except the identity key).
 Options:
   -h, --help:                Print this usage message and exit.
@@ -1355,7 +1356,7 @@
 
 #----------------------------------------------------------------------
 _PRINT_STATS_USAGE = """\
-Usage: mixminion server-stats [options]
+Usage: mixminiond stats [options]
 Print server statistics for the current statistics interval.
 Options:
   -h, --help:                Print this usage message and exit.
@@ -1373,7 +1374,7 @@
 
 #----------------------------------------------------------------------
 _SIGNAL_SERVER_USAGE = """\
-Usage: mixminion %s [options]
+Usage: mixminiond %s [options]
 Tell a mixminion server to %s.
 Options:
   -h, --help:                Print this usage message and exit.
@@ -1385,11 +1386,11 @@
        server."""
     if cmd.endswith("stop"):
         sig_reload = 0
-        usage = _SIGNAL_SERVER_USAGE % ("server-stop", "shut down")
+        usage = _SIGNAL_SERVER_USAGE % ("stop", "shut down")
     else:
         assert cmd.endswith("reload")
         sig_reload = 1
-        usage = _SIGNAL_SERVER_USAGE % ("server-reload",
+        usage = _SIGNAL_SERVER_USAGE % ("reload",
                                         "rescan its configuration")
 
     config = configFromServerArgs(cmd, args, usage=usage)
@@ -1429,7 +1430,7 @@
 
 #----------------------------------------------------------------------
 _REPUBLISH_USAGE = """\
-Usage: mixminion server-republish [options]
+Usage: mixminiond republish [options]
 Force a mixminion server to republish its keys to the directory.
 Options:
   -h, --help:                Print this usage message and exit.
@@ -688,7 +688,7 @@
         # Try to read the keyring.  If we have a pre-0.0.4 version of
         # mixminion, we might have some bad server descriptors lying
-        # around.  If so, tell the user to run server-upgrade.
+        # around.  If so, tell the user to run 'mixminiond upgrade.'
         try:
             self.keyring = mixminion.server.ServerKeys.ServerKeyring(config)